@@ -516,14 +516,18 @@ TmaidWindow *
 file_open_edit (const gchar *file)
 {
   gchar *ext, *p, *text, **charset, *utf8str;
-  gint i, x, y;
+  gint i;
   TmaidWindow *tmaid;
   GdkBitmap *mask;
   GdkPixmap *pixmap;
   GdkRectangle rc;
-  GtkWidget *preedit, *table, *menu_shell, *hbox, *button, *frame;
+  GtkWidget *table, *menu_shell, *hbox, *button, *frame;
+#ifndef G_OS_WIN32
+  gint x, y;
+  GtkWidget *preedit;
+#endif /* not G_OS_WIN32 */
   static gint fcount = 0;   /* ja:新規ファイルの数 */
-    static gchar *xpm[] = {
+  static gchar *xpm[] = {
 "8 7 2 1",
 "   c None",
 ".  c #000000",
@@ -590,18 +594,24 @@ file_open_edit (const gchar *file)
   tmaid->im_context = gtk_im_multicontext_new ();
   g_signal_connect (tmaid->im_context, "commit",
                             G_CALLBACK (signal_commit), tmaid);
+#ifndef G_OS_WIN32
   g_signal_connect (tmaid->im_context, "preedit-changed",
                             G_CALLBACK (signal_preedit_changed), tmaid);
+#endif /* not G_OS_WIN32 */
   g_signal_connect (tmaid->im_context, "retrieve-surrounding",
                             G_CALLBACK (signal_retrieve_surrounding), tmaid);
   g_signal_connect (tmaid->im_context, "delete-surrounding",
                             G_CALLBACK (signal_delete_surrounding), tmaid);
+#ifdef G_OS_WIN32
+  gtk_im_context_set_use_preedit (tmaid->im_context, FALSE);
+#else /* not G_OS_WIN32 */
   preedit = gtk_window_new (GTK_WINDOW_POPUP);
   tmaid->preedit = gtk_drawing_area_new ();
   g_signal_connect (G_OBJECT (tmaid->preedit), "expose-event",
                                     G_CALLBACK (signal_expose_preedit), tmaid);
   gtk_container_add (GTK_CONTAINER (preedit), tmaid->preedit);
   gtk_widget_show (tmaid->preedit);
+#endif /* not G_OS_WIN32 */
 
   /* ja:表示エリア */
   tmaid->drawing = gtk_drawing_area_new ();
@@ -703,8 +713,10 @@ file_open_edit (const gchar *file)
   /* ja:Input Method */
   while (gtk_events_pending ())
     gtk_main_iteration ();
+#ifndef G_OS_WIN32
   gdk_window_get_origin (tmaid->drawing->window, &x, &y);
   gtk_window_move (GTK_WINDOW (gtk_widget_get_parent (tmaid->preedit)), x, y);
+#endif /* not G_OS_WIN32 */
   rc.x = rc.y = rc.width = 0;
   rc.height = tmaid->font_height;
   gtk_im_context_set_cursor_location (tmaid->im_context, &rc);
