@@ -67,7 +67,9 @@ draw_caret (TmaidWindow *tmaid,
   gint x, y;
   guint context_id;
   GdkRectangle rc;
+#ifndef G_OS_WIN32
   GtkWidget *widget;
+#endif /* not G_OS_WIN32 */
 
   if (cursor && timer_id != 0
             && (tmaid->cursor.x != cursor->x || tmaid->cursor.y != cursor->y))
@@ -107,17 +109,17 @@ draw_caret (TmaidWindow *tmaid,
   gtk_statusbar_pop (GTK_STATUSBAR (status), context_id);
   gtk_statusbar_push (GTK_STATUSBAR (status), context_id, text);
   g_free (text);
+#ifndef G_OS_WIN32
   gdk_window_get_origin (tmaid->drawing->window, &x, &y);
   widget = gtk_widget_get_parent (tmaid->preedit);
   visible = GTK_WIDGET_VISIBLE (widget);
   if (!visible)
-    {
-      gtk_window_resize (GTK_WINDOW (widget), 1, 1);
-      gtk_widget_show (widget);
-    }
+    gtk_window_resize (GTK_WINDOW (widget), 1, 1);
+  gtk_widget_hide (widget);
   gtk_window_move (GTK_WINDOW (widget), rc.x + x, rc.y + y);
-  if (!visible)
-    gtk_widget_hide (widget);
+  if (visible)
+    gtk_widget_show (widget);
+#endif /* not G_OS_WIN32 */
   rc.width = 0;
   gtk_im_context_set_cursor_location (tmaid->im_context, &rc);
 }
