@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 /******************************************************************************
 *                                                                             *
 * ja:一般関数群                                                               *
@@ -128,4 +133,9 @@ void
 tab_operation (TmaidWindow *tmaid);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
