@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 typedef struct ReplaceInfo_Tag
 {
   gboolean arrow;
@@ -44,4 +49,9 @@ gint
 repinfo_dialog (ReplaceInfo *ri);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
