@@ -64,15 +64,19 @@ signal_focus_in (GtkWidget     *widget,
                  GdkEventFocus *event,
                  TmaidWindow   *tmaid)
 {
+#ifndef G_OS_WIN32
   gchar *str;
+#endif /* not G_OS_WIN32 */
 
   GTK_WIDGET_SET_FLAGS (widget, GTK_HAS_FOCUS);
+#ifndef G_OS_WIN32
   gtk_im_context_get_preedit_string (tmaid->im_context, &str, NULL, NULL);
   if (g_strlen (str) > 0)
     gtk_widget_show (gtk_widget_get_parent (tmaid->preedit));
   else
     gtk_widget_hide (gtk_widget_get_parent (tmaid->preedit));
   g_free (str);
+#endif /* not G_OS_WIN32 */
   gtk_im_context_focus_in (tmaid->im_context);
   draw_caret (tmaid, NULL);
   return FALSE;
@@ -85,7 +89,9 @@ signal_focus_out (GtkWidget     *widget,
                   TmaidWindow   *tmaid)
 {
   GTK_WIDGET_UNSET_FLAGS (widget, GTK_HAS_FOCUS);
+#ifndef G_OS_WIN32
   gtk_widget_hide (gtk_widget_get_parent (tmaid->preedit));
+#endif /* not G_OS_WIN32 */
   gtk_im_context_focus_out (tmaid->im_context);
   draw_caret (tmaid, NULL);
   return FALSE;
@@ -217,7 +223,9 @@ signal_destroy_draw (GtkWidget   *widget,
   delete_list (&tmaid->undo);
   delete_list (&tmaid->redo);
   /* en:Input Method */
+#ifndef G_OS_WIN32
   gtk_widget_destroy (gtk_widget_get_parent (tmaid->preedit));
+#endif /* G_OS_WIN32 */
   g_signal_connect_swapped (G_OBJECT (window), "destroy",
                     G_CALLBACK (g_object_unref), G_OBJECT (tmaid->im_context));
   g_free (tmaid);
@@ -266,33 +274,37 @@ signal_commit (GtkIMContext *im_context,
         set_menu_bar (tmaid);
       tmaid_change_edit (tmaid, TRUE);
     }
+#ifndef G_OS_WIN32
   gtk_im_context_get_preedit_string (im_context, &str, NULL, NULL);
   if (g_strlen (str) <= 0)
     gtk_widget_hide (gtk_widget_get_parent (tmaid->preedit));
+#endif /* not G_OS_WIN32 */
 }
 
 
+#ifndef G_OS_WIN32
 void
 signal_preedit_changed (GtkIMContext *im_context,
                         TmaidWindow  *tmaid)
 {
-  int width, height;
   gchar *str;
-  gint cursor_pos;
-  PangoAttrList *attrs;
   GtkWidget *widget;
+  PangoAttrList *attrs;
 
-  gtk_im_context_get_preedit_string (im_context, &str, &attrs, &cursor_pos);
+  gtk_im_context_get_preedit_string (im_context, &str, &attrs, NULL);
   widget = gtk_widget_get_parent (tmaid->preedit);
   if (g_strlen (str) > 0)
     {
+      int width;
+
       pango_layout_set_text (tmaid->layout, str, -1);
       pango_layout_set_attributes (tmaid->layout, attrs);
-      pango_layout_get_pixel_size (tmaid->layout, &width, &height);
+      pango_layout_get_pixel_size (tmaid->layout, &width, NULL);
       pango_layout_set_attributes (tmaid->layout, NULL);
-      gtk_window_resize (GTK_WINDOW (widget), width, height);
+      gtk_window_resize (GTK_WINDOW (widget), width, tmaid->font_height);
       gtk_widget_show (widget);
-      gtk_widget_queue_draw_area (tmaid->preedit, 0, 0, width, height);
+      gtk_widget_queue_draw_area (tmaid->preedit,
+                                            0, 0, width, tmaid->font_height);
     }
   else
     {
@@ -301,6 +313,7 @@ signal_preedit_changed (GtkIMContext *im_context,
   g_free (str);
   pango_attr_list_unref (attrs);
 }
+#endif /* not G_OS_WIN32 */
 
 
 gboolean
@@ -326,6 +339,7 @@ signal_delete_surrounding (GtkIMContext *imcontext,
 }
 
 
+#ifndef G_OS_WIN32
 gboolean
 signal_expose_preedit (GtkWidget      *widget,
                        GdkEventExpose *event,
@@ -361,6 +375,7 @@ signal_expose_preedit (GtkWidget      *widget,
   pango_layout_set_attributes (tmaid->layout, NULL);
   return TRUE;
 }
+#endif /* not G_OS_WIN32 */
 
 
 /******************************************************************************
