@@ -29,163 +29,189 @@
 
 /******************************************************************************
 *                                                                             *
-* シグナル/イベント関数群(テキスト)                                           *
+* ja:シグナル/イベント関数群(テキスト)                                        *
 *                                                                             *
 ******************************************************************************/
-void signal_style_set(GtkWidget *widget,GtkStyle *style,gpointer user_data)
+void
+signal_style_set (GtkWidget *widget,
+                  GtkStyle  *style,
+                  gpointer   user_data)
 {
-    gint i;
-    GList *glist;
-    TmaidWindow *tmaid;
+  gint i;
+  GList *glist;
+  TmaidWindow *tmaid;
 
-    /* システム色 */
-    style=gtk_widget_get_style(widget);
-    system_color[0]=style->text[0];
-    system_color[1]=style->base[0];
-    system_color[2]=style->dark[0];
-    system_color[3]=style->dark[0];
-    system_color[4]=style->dark[0];
-    system_color[5]=style->dark[0];
-    system_color[6]=style->dark[0];
-    system_color[7]=style->mid[0];
-    system_color[8]=style->fg[3];
-    system_color[9]=style->bg[3];
-    if (system_font!=NULL)
-        pango_font_description_free (system_font);
-    /* システムフォント */
-    system_font = pango_font_description_copy
+  /* ja:システム色 */
+  style = gtk_widget_get_style (widget);
+  system_color[0] = style->text[0];
+  system_color[1] = style->base[0];
+  system_color[2] = style->dark[0];
+  system_color[3] = style->dark[0];
+  system_color[4] = style->dark[0];
+  system_color[5] = style->dark[0];
+  system_color[6] = style->dark[0];
+  system_color[7] = style->mid[0];
+  system_color[8] = style->fg[3];
+  system_color[9] = style->bg[3];
+  if (system_font)
+    pango_font_description_free (system_font);
+  /* ja:システムフォント */
+  system_font = pango_font_description_copy
                                     (pango_context_get_font_description
                                     (gtk_widget_get_pango_context (widget)));
-    glist=gtk_container_children(GTK_CONTAINER(notebook));
-    for (i=g_list_length(glist)-1;i>=0;i--) {
-        tmaid = g_object_get_data (G_OBJECT (g_list_nth_data (glist, i)),
+  glist = gtk_container_children (GTK_CONTAINER (notebook));
+  for (i = g_list_length (glist) - 1; i >= 0; i--)
+    {
+      tmaid = g_object_get_data (G_OBJECT (g_list_nth_data (glist, i)),
                                                                 "user_data");
-        if (tmaid->ft.syscol || tmaid->ft.font_name==NULL) {
-            if (tmaid->ft.font_name==NULL) {
-                /* フォント変更 */
-                g_object_unref (tmaid->layout);
-                gtk_widget_modify_font (tmaid->drawing,
+      if (tmaid->ft.syscol || !tmaid->ft.font_name)
+        {
+          if (!tmaid->ft.font_name)
+            {
+              /* ja:フォント変更 */
+              g_object_unref (tmaid->layout);
+              gtk_widget_modify_font (tmaid->drawing,
                                     pango_font_description_copy (system_font));
-                tmaid->layout = gtk_widget_create_pango_layout
+              tmaid->layout = gtk_widget_create_pango_layout
                                                         (tmaid->drawing, NULL);
-                charset_size (tmaid->layout,
+              charset_size (tmaid->layout,
                     &tmaid->font_width, &tmaid->font_height, tmaid->font_buf);
-                /* スクロールバー */
-                tmaid->cursor.x=tmaid->cursor.y=tmaid->top.x=tmaid->top.y=0;
-                modify_margin(tmaid);
-                misc_set_scroll_bar (tmaid->hscroll,
+              /* ja:スクロールバー */
+              tmaid->cursor.x = tmaid->cursor.y
+                                            = tmaid->top.x = tmaid->top.y = 0;
+              modify_margin (tmaid);
+              misc_set_scroll_bar (tmaid->hscroll,
                     G_CALLBACK (signal_value_changed_hscroll), tmaid,
                     0, edit_get_width_max (tmaid) + 1,
                     MAX (tmaid->drawing->allocation.width / tmaid->font_width,
                                                             1), tmaid->top.x);
-                misc_set_scroll_bar (tmaid->vscroll,
+              misc_set_scroll_bar (tmaid->vscroll,
                     G_CALLBACK (signal_value_changed_vscroll), tmaid,
                     0, tmaid->max,
                     MAX (tmaid->drawing->allocation.height
                                     / tmaid->font_height, 1), tmaid->top.y);
             }
-            gtk_widget_draw(tmaid->drawing,NULL);/* 再描画 */
+          gtk_widget_draw (tmaid->drawing, NULL);/* ja:再描画 */
         }
     }
-    g_list_free(glist);
+  g_list_free (glist);
 }
 
 
 /******************************************************************************
 *                                                                             *
-* シグナル/イベント関数群(メニュー)                                           *
+* ja:シグナル/イベント関数群(メニュー)                                        *
 *                                                                             *
 ******************************************************************************/
-void signal_activate_menu_window(GtkWidget *widget,GtkWidget *child)
+void
+signal_activate_menu_window (GtkWidget *widget, GtkWidget *child)
 {
-    gtk_notebook_set_page(GTK_NOTEBOOK(notebook),
-                        gtk_notebook_page_num(GTK_NOTEBOOK(notebook),child));
-    gtk_widget_grab_focus (((TmaidWindow *)
+  gtk_notebook_set_page (GTK_NOTEBOOK (notebook),
+                    gtk_notebook_page_num (GTK_NOTEBOOK (notebook), child));
+  gtk_widget_grab_focus (((TmaidWindow *)
                 g_object_get_data (G_OBJECT (child), "user_data"))->drawing);
 }
 
 
-void signal_activate_menu_history(GtkWidget *widget,gchar *file)
+void
+signal_activate_menu_history (GtkWidget *widget,
+                              gchar     *file)
 {
-    file_open_edit(file);
+  file_open_edit (file);
 }
 
 
-void signal_destroy_menu_history(GtkWidget *widget,gchar *file)
+void
+signal_destroy_menu_history (GtkWidget *widget,
+                             gchar     *file)
 {
-    g_free(file);
+  g_free (file);
 }
 
 
 /******************************************************************************
 *                                                                             *
-* シグナル/イベント関数群(ノート)                                             *
-*                                                                             *
-******************************************************************************/
-void signal_clicked(GtkWidget *widget,GtkWidget *child)
-{
-    if (prompt_close ((TmaidWindow *)g_object_get_data (G_OBJECT (child),
-                                                                "user_data")))
-        gtk_notebook_remove_page (GTK_NOTEBOOK (notebook),
-                        gtk_notebook_page_num (GTK_NOTEBOOK (notebook), child));
-}
-
-
-void signal_switch_page(GtkNotebook *notebook,GtkNotebookPage *page,
-                                            gint page_num,gpointer user_data)
-{
-    TmaidWindow *tmaid;
-
-    tmaid = g_object_get_data
-                    (G_OBJECT (gtk_notebook_get_nth_page (notebook, page_num)),
-                                                                "user_data");
-    /* メニュー表示 */
-    set_menu_bar(tmaid);
-}
-
-
-void signal_destroy_notebook(GtkWidget *widget,gpointer user_data)
-{
-    gtk_timeout_remove(timer_id);
-}
-
-
-/******************************************************************************
-*                                                                             *
-* シグナル/イベント関数群(セレクション)                                       *
+* ja:シグナル/イベント関数群(ノート)                                          *
 *                                                                             *
 ******************************************************************************/
 void
-signal_drag_data_received (GtkWidget *widget, GdkDragContext *context,
-    gint x, gint y, GtkSelectionData *selection_data, guint info, guint time)
+signal_clicked (GtkWidget *widget,
+                GtkWidget *child)
 {
-    gchar *file, **files;
-    gint i;
-
-    files = g_strsplit (selection_data->data, "\r\n", G_MAXINT);
-    for (i = 0; files[i] != NULL; i++)
-      {
-        file = g_filename_from_uri (files[i], NULL, NULL);
-        if (file != NULL)
-          {
-            file_open_edit (file);
-            g_free (file);
-          }
-      }
-    g_strfreev (files);
+  if (prompt_close ((TmaidWindow *)g_object_get_data (G_OBJECT (child),
+                                                                "user_data")))
+    gtk_notebook_remove_page (GTK_NOTEBOOK (notebook),
+                    gtk_notebook_page_num (GTK_NOTEBOOK (notebook), child));
 }
 
 
-gboolean signal_selection_clear(GtkWidget *widget,GdkEventSelection *event,
-                                                            gpointer user_data)
+void
+signal_switch_page (GtkNotebook     *notebook,
+                    GtkNotebookPage *page,
+                    gint             page_num,
+                    gpointer         user_data)
 {
-    if (event->selection == GDK_SELECTION_CLIPBOARD)
-      {
-        /* クリップボード */
-        g_free (clipboard_text);
-        clipboard_text = NULL;
-      }
-    return TRUE;
+  TmaidWindow *tmaid;
+
+  tmaid = g_object_get_data
+                    (G_OBJECT (gtk_notebook_get_nth_page (notebook, page_num)),
+                                                                "user_data");
+  /* ja:メニュー表示 */
+  set_menu_bar (tmaid);
+}
+
+
+void
+signal_destroy_notebook (GtkWidget *widget,
+                         gpointer   user_data)
+{
+  gtk_timeout_remove (timer_id);
+}
+
+
+/******************************************************************************
+*                                                                             *
+* ja:シグナル/イベント関数群(セレクション)                                    *
+*                                                                             *
+******************************************************************************/
+void
+signal_drag_data_received (GtkWidget        *widget,
+                           GdkDragContext   *context,
+                           gint              x,
+                           gint              y,
+                           GtkSelectionData *selection_data,
+                           guint             info,
+                           guint             time)
+{
+  gchar *file, **files;
+  gint i;
+
+  files = g_strsplit (selection_data->data, "\r\n", G_MAXINT);
+  for (i = 0; files[i] != NULL; i++)
+    {
+      file = g_filename_from_uri (files[i], NULL, NULL);
+      if (file)
+        {
+          file_open_edit (file);
+          g_free (file);
+        }
+    }
+  g_strfreev (files);
+}
+
+
+gboolean
+signal_selection_clear (GtkWidget         *widget,
+                        GdkEventSelection *event,
+                        gpointer           user_data)
+{
+  if (event->selection == GDK_SELECTION_CLIPBOARD)
+    {
+      /* ja:クリップボード */
+      g_free (clipboard_text);
+      clipboard_text = NULL;
+    }
+  return TRUE;
 }
 
 
@@ -196,9 +222,8 @@ signal_selection_get (GtkWidget        *widget,
                       guint             time,
                       TmaidWindow      *tmaid)
 {
-
   if (data->selection==GDK_SELECTION_PRIMARY && tmaid && tmaid->select.x >= 0)
-      /* ja:プライマリセレクション */
+    /* ja:プライマリセレクション */
     {
       gchar *text;
       gint length = 0;
@@ -222,8 +247,8 @@ signal_selection_get (GtkWidget        *widget,
 void
 signal_selection_received (GtkWidget        *widget,
                            GtkSelectionData *data,
-                           guint time,
-                           gpointer user_data)
+                           guint             time,
+                           gpointer          user_data)
 {
   if (data->selection == GDK_SELECTION_PRIMARY
                                 || data->selection == GDK_SELECTION_CLIPBOARD)
@@ -359,39 +384,45 @@ signal_selection_recv (GObject   *object,
 
 /******************************************************************************
 *                                                                             *
-* シグナル/イベント関数群(メイン)                                             *
+* ja:シグナル/イベント関数群(メイン)                                          *
 *                                                                             *
 ******************************************************************************/
-gboolean signal_delete(GtkWidget *widget,GdkEvent *event,gpointer user_data)
+gboolean
+signal_delete (GtkWidget *widget,
+               GdkEvent  *event,
+               gpointer   user_data)
 {
-    gint page;
-    TmaidWindow *tmaid;
+  gint page;
+  TmaidWindow *tmaid;
 
-    while ((page=gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))>=0) {
-        tmaid = g_object_get_data (G_OBJECT
+  while ((page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook))) >= 0)
+    {
+      tmaid = g_object_get_data (G_OBJECT
                 (gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), page)),
                                                                 "user_data");
-        if (!prompt_close(tmaid))
-            return TRUE;
-        gtk_notebook_remove_page(GTK_NOTEBOOK(notebook),page);
+      if (!prompt_close (tmaid))
+        return TRUE;
+      gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), page);
     }
-    return FALSE;
+  return FALSE;
 }
 
 
-void signal_destroy_window(GtkWidget *widget,gpointer user_data)
+void
+signal_destroy_window (GtkWidget *widget,
+                       gpointer   user_data)
 {
-    gint i;
-    GList *glist;
-    GtkWidget *menu_shell;
+  gint i;
+  GList *glist;
+  GtkWidget *menu_shell;
 
-    memset(history_files,0,sizeof(gchar *)*10);
-    menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/File");
-    glist = gtk_container_children (GTK_CONTAINER (menu_shell));
-    for (i=0;i<(gint)g_list_length(glist)-MENUFILE-1;i++)
-        history_files[i] = g_strdup (g_object_get_data
+  memset (history_files, 0, sizeof (gchar *) * 10);
+  menu_shell = gtk_item_factory_get_widget (ifactory_menu, "<main>/File");
+  glist = gtk_container_children (GTK_CONTAINER (menu_shell));
+  for (i = 0; i < (gint)g_list_length (glist) - MENUFILE - 1; i++)
+    history_files[i] = g_strdup (g_object_get_data
                         (G_OBJECT (g_list_nth_data (glist, i + MENUFILE - 1)),
                                                                 "user_data"));
-    g_list_free(glist);
-    gtk_main_quit();
+  g_list_free (glist);
+  gtk_main_quit ();
 }
