@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 typedef struct ToolBar_Tag
 {
   gchar                   *name;
@@ -36,4 +41,9 @@ typedef struct ToolBar_Tag
 extern ToolBar toolbar_items[];
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
